#ifndef XINEMACONTROL_H_
#define XINEMACONTROL_H_

#include <QObject>
#include <QTcpSocket>

class XinemaControl: public QObject
{
	Q_OBJECT

public:
	enum PlaybackState
	{
		STOPPED,
		PAUSED,
		PLAYING
	};

private:
	QTcpSocket socket;
	QByteArray buffer;
	PlaybackState playback_state;
	QString title;
	float duration;
	float position;

public:
	XinemaControl();

	void connect(const QHostAddress &);
	bool is_connected() const;

	void list_directory(const QString &);
	void play_file(const QString &);

	PlaybackState get_playback_state() const { return playback_state; }
	const QString &get_title() const { return title; }
	float get_duration() const { return duration; }
	float get_position() const { return position; }

	void play();
	void seek(float);
	void pause();
	void stop();

signals:
	void connected();
	void disconnected();
	void directory_started(const QString &);
	void file_added(const QString &);
	void subdirectory_added(const QString &);
	void playback_state_changed(PlaybackState);
	void title_changed(const QString &);
	void duration_changed(float);
	void position_changed(float);

private:
	void send_request(const QString &);

private slots:
	void data_available();
	void process_reply(const QString &);
};

#endif
